@@ -8,12 +8,15 @@ class SummernoteWidget(forms.Textarea):
     def render(self, name, value, attrs=None):
         attrs_for_textarea = attrs.copy()
         attrs_for_textarea['hidden'] = 'true'
-        html = super(SummernoteWidget, self).render(name, value, attrs_for_textarea)
+        html = super(SummernoteWidget, self).render(name,
+                                                    value,
+                                                    attrs_for_textarea)
 
         final_attrs = self.build_attrs(attrs)
         del final_attrs['id']
 
         url = reverse_lazy('django_summernote-editor', args=(attrs['id'],))
-        html += '<iframe src="%s" width="720" height="320" frameborder="0"%s></iframe>' % (url, flatatt(final_attrs))
+        html += '<iframe id="%s-iframe" src="%s" width="720" height="320" frameborder="0"%s></iframe>' \
+            % (attrs['id'], url, flatatt(final_attrs))
 
         return mark_safe(html)
